.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Tools for unit testing
======================

Fixture overview
^^^^^^^^^^^^^^^^

.. uml:: ../../../reahl-web/reahl/web_dev/fixtures.puml


Basic fixtures
^^^^^^^^^^^^^^

.. automodule:: reahl.dev.fixtures

ContextAwareFixture
"""""""""""""""""""

.. autoclass:: reahl.dev.fixtures.ContextAwareFixture
   :members:

ReahlSystemSessionFixture
"""""""""""""""""""""""""

.. autoclass:: reahl.dev.fixtures.ReahlSystemSessionFixture
   :members:

ReahlSystemFixture
""""""""""""""""""

.. autoclass:: reahl.dev.fixtures.ReahlSystemFixture
   :members:

Managing a SqlAlchemy database
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

SqlAlchemyFixture
"""""""""""""""""

.. autoclass:: reahl.sqlalchemysupport_dev.fixtures.SqlAlchemyFixture
   :members:

Web development fixtures
^^^^^^^^^^^^^^^^^^^^^^^^

WebServerFixture
""""""""""""""""

.. autoclass:: reahl.web_dev.fixtures.WebServerFixture
   :members:


WebFixture
""""""""""

.. autoclass:: reahl.web_dev.fixtures.WebFixture
   :members:


General web development tools
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

ReahlWebServer
""""""""""""""

.. autoclass:: reahl.webdev.webserver.ReahlWebServer
   :members:

